==> moodle-2.0.tbz: www/moodle/blocks/section_links/lang/en/block_section_links.php <==
<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'block_section_links', language 'en', branch 'MOODLE_20_STABLE'
 *
 * @package   block_section_links
 * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['incbydesc1'] = 'This is the value the section is incremented each time a section link is displayed starting at 1.';
$string['incbydesc2'] = 'This is the value the section is incremented each time a section link is displayed starting at 1.';
$string['incby1'] = 'Increase by';
$string['incby2'] = 'Alternative Increase by';
$string['jumptocurrenttopic'] = 'Jump to current topic';
$string['jumptocurrentweek'] = 'Jump to current week';
$string['numsectionsdesc1'] = 'Once the number of sections in the course reaches this number then the increment by value is used.';
$string['numsectionsdesc2'] = 'Once the number of sections in the course reaches this number then the Alternative increment by value is used.';
$string['numsections1'] = 'Number of sections';
$string['numsections2'] = 'Alternative number of sections';
$string['pluginname'] = 'Section links';
$string['topics'] = 'Topics';
$string['weeks'] = 'Weeks';

==> moodle-2.2.3.tbz: www/moodle/blocks/section_links/lang/en/block_section_links.php <==
<?php

// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'block_section_links', language 'en', branch 'MOODLE_20_STABLE'
 *
 * @package   block_section_links
 * @copyright 1999 onwards Martin Dougiamas  {@link http://moodle.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['incbydesc1'] = 'This is the value the section is incremented each time a section link is displayed starting at 1.';
$string['incbydesc2'] = 'This is the value the section is incremented each time a section link is displayed starting at 1.';
$string['incby1'] = 'Increase by';
$string['incby2'] = 'Alternative increase by';
$string['jumptocurrenttopic'] = 'Jump to current topic';
$string['jumptocurrentweek'] = 'Jump to current week';
$string['numsectionsdesc1'] = 'Once the number of sections in the course reaches this number then the increment by value is used.';
$string['numsectionsdesc2'] = 'Once the number of sections in the course reaches this number then the Alternative increment by value is used.';
$string['numsections1'] = 'Number of sections';
$string['numsections2'] = 'Alternative number of sections';
$string['pluginname'] = 'Section links';
$string['topics'] = 'Topics';
$string['weeks'] = 'Weeks';
